package cn.minestar.agriculture.service;

import cn.minestar.agriculture.entity.WxMiniLabel;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author www.minestar.cn/
 * @date 2021-08-12
 */
public interface IWxMiniLabelService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public WxMiniLabel selectWxMiniLabelById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniLabel 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<WxMiniLabel> selectWxMiniLabelList(WxMiniLabel wxMiniLabel);

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniLabel 【请填写功能名称】
     * @return 结果
     */
    public int insertWxMiniLabel(WxMiniLabel wxMiniLabel);

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniLabel 【请填写功能名称】
     * @return 结果
     */
    public int updateWxMiniLabel(WxMiniLabel wxMiniLabel);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniLabelByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniLabelById(Long id);
}
